@@ -24,6 +24,8 @@ Token::TokenType Token::tokenType(QStringView token)
         return PDF417;
     } else if (token.startsWith(QLatin1String("code39:"), Qt::CaseInsensitive)) {
         return Code39;
+    } else if (token.startsWith(QLatin1String("ean13:"), Qt::CaseInsensitive)) {
+        return EAN13;
     } else if (token.startsWith(QLatin1String("http"), Qt::CaseInsensitive)) {
         return Url;
     }
@@ -48,6 +50,8 @@ QVariant Token::tokenData(const QString &token)
         return token.mid(7);
     } else if (token.startsWith(QLatin1String("pdf417bin:"), Qt::CaseInsensitive)) {
         return QByteArray::fromBase64(QStringView(token).mid(10).toLatin1());
+    } else if (token.startsWith(QLatin1String("ean13:"), Qt::CaseInsensitive)) {
+        return token.mid(6);
     } else if (token.startsWith(QLatin1String("code39:"), Qt::CaseInsensitive)) {
         return token.mid(7);
     }
